#ifndef LINUX_2_2
#include "/home/alsa/kernel/linux-2.6.17.8/include/linux/pci_ids.h"
#endif

/* bt87x */
#ifndef PCI_VENDOR_ID_BROOKTREE
#define PCI_VENDOR_ID_BROOKTREE		0x109e
#endif
#ifndef PCI_DEVICE_ID_BROOKTREE_878
#define PCI_DEVICE_ID_BROOKTREE_878	0x0878
#endif
#ifndef PCI_DEVICE_ID_BROOKTREE_879
#define PCI_DEVICE_ID_BROOKTREE_879	0x0879
#endif

/* cmipci */
#ifndef PCI_VENDOR_ID_CMEDIA
#define PCI_VENDOR_ID_CMEDIA		0x13f6
#endif
#ifndef PCI_DEVICE_ID_CMEDIA_CM8338A
#define PCI_DEVICE_ID_CMEDIA_CM8338A	0x0100
#endif
#ifndef PCI_DEVICE_ID_CMEDIA_CM8338B
#define PCI_DEVICE_ID_CMEDIA_CM8338B	0x0101
#endif
#ifndef PCI_DEVICE_ID_CMEDIA_CM8738
#define PCI_DEVICE_ID_CMEDIA_CM8738	0x0111
#endif
#ifndef PCI_DEVICE_ID_CMEDIA_CM8738B
#define PCI_DEVICE_ID_CMEDIA_CM8738B	0x0112
#endif

/* cs4281 */
#ifndef PCI_VENDOR_ID_CIRRUS
#define PCI_VENDOR_ID_CIRRUS		0x1013
#endif
#ifndef PCI_DEVICE_ID_CIRRUS_4281
#define PCI_DEVICE_ID_CIRRUS_4281	0x6005
#endif

/* ens1370/1 */
#ifndef PCI_DEVICE_ID_ENSONIQ_CT5880
#define PCI_DEVICE_ID_ENSONIQ_CT5880    0x5880
#endif
#ifndef PCI_DEVICE_ID_ENSONIQ_ES1371
#define PCI_DEVICE_ID_ENSONIQ_ES1371	0x1371
#endif

/* es1938 */
#ifndef PCI_VENDOR_ID_ESS
#define PCI_VENDOR_ID_ESS		0x125d
#endif
#ifndef PCI_DEVICE_ID_ESS_AUDIOPCI
#define PCI_DEVICE_ID_ESS_AUDIOPCI	0x1969
#endif

/* es1968 */
#ifndef PCI_VENDOR_ID_ESS_OLD
#define PCI_VENDOR_ID_ESS_OLD		0x1285
#endif
#ifndef PCI_DEVICE_ID_ESS_ESS1978
#define PCI_DEVICE_ID_ESS_ESS1978	0x1978
#endif
#ifndef PCI_DEVICE_ID_ESS_ESS1968
#define PCI_DEVICE_ID_ESS_ESS1968	0x1968
#endif
#ifndef PCI_DEVICE_ID_ESS_ESS0100
#define PCI_DEVICE_ID_ESS_ESS0100	0x0100
#endif

/* intel8x0 */
#ifndef PCI_DEVICE_ID_INTEL_82801AA_5
#define PCI_DEVICE_ID_INTEL_82801AA_5	0x2415
#endif
#ifndef PCI_DEVICE_ID_INTEL_82801AB_5
#define PCI_DEVICE_ID_INTEL_82801AB_5	0x2425
#endif
#ifndef PCI_DEVICE_ID_INTEL_82801BA_4
#define PCI_DEVICE_ID_INTEL_82801BA_4	0x2445
#endif
#ifndef PCI_DEVICE_ID_INTEL_440MX
#define PCI_DEVICE_ID_INTEL_440MX	0x7195
#endif
#ifndef PCI_DEVICE_ID_INTEL_82801CA_5
#define PCI_DEVICE_ID_INTEL_82801CA_5	0x2485
#endif
#ifndef PCI_DEVICE_ID_INTEL_82801DB_5
#define PCI_DEVICE_ID_INTEL_82801DB_5	0x24c5
#endif
#ifndef PCI_DEVICE_ID_INTEL_82801EB_5
#define PCI_DEVICE_ID_INTEL_82801EB_5	0x24d5
#endif
#ifndef PCI_DEVICE_ID_INTEL_ESB_5
#define PCI_DEVICE_ID_INTEL_ESB_5	0x25a6
#endif
#ifndef PCI_DEVICE_ID_INTEL_ICH6_18
#define PCI_DEVICE_ID_INTEL_ICH6_18	0x266e
#endif
#ifndef PCI_DEVICE_ID_INTEL_ICH7_20
#define PCI_DEVICE_ID_INTEL_ICH7_20	0x27de
#endif
#ifndef PCI_DEVICE_ID_INTEL_ESB2_14
#define PCI_DEVICE_ID_INTEL_ESB2_14	0x2698
#endif
#ifndef PCI_DEVICE_ID_SI_7012
#define PCI_DEVICE_ID_SI_7012		0x7012
#endif
#ifndef PCI_DEVICE_ID_NVIDIA_MCP1_AUDIO
#define PCI_DEVICE_ID_NVIDIA_MCP1_AUDIO	0x01b1
#endif
#ifndef PCI_DEVICE_ID_NVIDIA_CK804_AUDIO
#define PCI_DEVICE_ID_NVIDIA_CK804_AUDIO 0x0059
#endif
#ifndef PCI_DEVICE_ID_NVIDIA_MCP2_AUDIO
#define PCI_DEVICE_ID_NVIDIA_MCP2_AUDIO	0x006a
#endif
#ifndef PCI_DEVICE_ID_NVIDIA_CK8_AUDIO
#define PCI_DEVICE_ID_NVIDIA_CK8_AUDIO	0x008a
#endif
#ifndef PCI_DEVICE_ID_NVIDIA_MCP3_AUDIO
#define PCI_DEVICE_ID_NVIDIA_MCP3_AUDIO	0x00da
#endif
#ifndef PCI_DEVICE_ID_NVIDIA_CK8S_AUDIO
#define PCI_DEVICE_ID_NVIDIA_CK8S_AUDIO	0x00ea
#endif

/* intel8x0m */
#ifndef PCI_DEVICE_ID_INTEL_82801AA_6
#define PCI_DEVICE_ID_INTEL_82801AA_6	0x2416
#endif
#ifndef PCI_DEVICE_ID_INTEL_82801AB_6
#define PCI_DEVICE_ID_INTEL_82801AB_6	0x2426
#endif
#ifndef PCI_DEVICE_ID_INTEL_82801BA_6
#define PCI_DEVICE_ID_INTEL_82801BA_6	0x2446
#endif
#ifndef PCI_DEVICE_ID_INTEL_440MX_6
#define PCI_DEVICE_ID_INTEL_440MX_6     0x7196
#endif
#ifndef PCI_DEVICE_ID_INTEL_82801CA_6
#define PCI_DEVICE_ID_INTEL_82801CA_6	0x2486
#endif
#ifndef PCI_DEVICE_ID_INTEL_82801DB_6
#define PCI_DEVICE_ID_INTEL_82801DB_6	0x24c6
#endif
#ifndef PCI_DEVICE_ID_INTEL_82801EB_6
#define PCI_DEVICE_ID_INTEL_82801EB_6	0x24d6
#endif
#ifndef PCI_DEVICE_ID_INTEL_ICH6_17
#define PCI_DEVICE_ID_INTEL_ICH6_17	0x266d
#endif
#ifndef PCI_DEVICE_ID_INTEL_ICH7_19
#define PCI_DEVICE_ID_INTEL_ICH7_19	0x27dd
#endif
#ifndef PCI_DEVICE_ID_SI_7013
#define PCI_DEVICE_ID_SI_7013		0x7013
#endif
#ifndef PCI_DEVICE_ID_NVIDIA_MCP1_MODEM
#define PCI_DEVICE_ID_NVIDIA_MCP1_MODEM	0x01c1
#endif
#ifndef PCI_DEVICE_ID_NVIDIA_MCP2_MODEM
#define PCI_DEVICE_ID_NVIDIA_MCP2_MODEM	0x0069
#endif
#ifndef PCI_DEVICE_ID_NVIDIA_MCP2S_MODEM
#define PCI_DEVICE_ID_NVIDIA_MCP2S_MODEM 0x0089
#endif
#ifndef PCI_DEVICE_ID_NVIDIA_MCP3_MODEM
#define PCI_DEVICE_ID_NVIDIA_MCP3_MODEM	0x00d9
#endif

/* maestro3 */
#ifndef PCI_DEVICE_ID_ESS_ALLEGRO_1
#define PCI_DEVICE_ID_ESS_ALLEGRO_1	0x1988
#endif
#ifndef PCI_DEVICE_ID_ESS_ALLEGRO
#define PCI_DEVICE_ID_ESS_ALLEGRO	0x1989
#endif
#ifndef PCI_DEVICE_ID_ESS_CANYON3D_2LE
#define PCI_DEVICE_ID_ESS_CANYON3D_2LE	0x1990
#endif
#ifndef PCI_DEVICE_ID_ESS_CANYON3D_2
#define PCI_DEVICE_ID_ESS_CANYON3D_2	0x1992
#endif
#ifndef PCI_DEVICE_ID_ESS_MAESTRO3
#define PCI_DEVICE_ID_ESS_MAESTRO3	0x1998
#endif
#ifndef PCI_DEVICE_ID_ESS_MAESTRO3_1
#define PCI_DEVICE_ID_ESS_MAESTRO3_1	0x1999
#endif
#ifndef PCI_DEVICE_ID_ESS_MAESTRO3_HW
#define PCI_DEVICE_ID_ESS_MAESTRO3_HW	0x199a
#endif
#ifndef PCI_DEVICE_ID_ESS_MAESTRO3_2
#define PCI_DEVICE_ID_ESS_MAESTRO3_2	0x199b
#endif

/* rme32 */
#ifndef PCI_VENDOR_ID_XILINX_RME
#define PCI_VENDOR_ID_XILINX_RME	0xea60
#endif
#ifndef PCI_DEVICE_ID_RME_DIGI32
#define PCI_DEVICE_ID_RME_DIGI32	0x9896
#endif
#ifndef PCI_DEVICE_ID_RME_DIGI32_PRO
#define PCI_DEVICE_ID_RME_DIGI32_PRO	0x9897
#endif
#ifndef PCI_DEVICE_ID_RME_DIGI32_8
#define PCI_DEVICE_ID_RME_DIGI32_8	0x9898
#endif

/* rme96 */
#ifndef PCI_VENDOR_ID_XILINX
#define PCI_VENDOR_ID_XILINX		0x10ee
#endif
#ifndef PCI_DEVICE_ID_RME_DIGI96
#define PCI_DEVICE_ID_RME_DIGI96	0x3fc0
#endif
#ifndef PCI_DEVICE_ID_RME_DIGI96_8
#define PCI_DEVICE_ID_RME_DIGI96_8	0x3fc1
#endif
#ifndef PCI_DEVICE_ID_RME_DIGI96_8_PRO
#define PCI_DEVICE_ID_RME_DIGI96_8_PRO	0x3fc2
#endif
#ifndef PCI_DEVICE_ID_RME_DIGI96_8_PAD_OR_PST
#define PCI_DEVICE_ID_RME_DIGI96_8_PAD_OR_PST 0x3fc3
#endif

/* sonicvibes */
#ifndef PCI_VENDOR_ID_S3
#define PCI_VENDOR_ID_S3		0x5333
#endif
#ifndef PCI_DEVICE_ID_S3_SONICVIBES
#define PCI_DEVICE_ID_S3_SONICVIBES	0xca00
#endif

/* via82xx */
#ifndef PCI_DEVICE_ID_VIA_82C686_5
#define PCI_DEVICE_ID_VIA_82C686_5	0x3058
#endif
#ifndef PCI_DEVICE_ID_VIA_8233_5
#define PCI_DEVICE_ID_VIA_8233_5	0x3059
#endif

/* ali5451 */
#ifndef PCI_VENDOR_ID_AL
#define PCI_VENDOR_ID_AL		0x10b9
#endif
#ifndef PCI_DEVICE_ID_AL_M5451
#define PCI_DEVICE_ID_AL_M5451		0x5451
#endif

/* au88x0 */
#ifndef PCI_VENDOR_ID_AUREAL
#define PCI_VENDOR_ID_AUREAL		0x12eb
#endif
#ifndef PCI_DEVICE_ID_AUREAL_VORTEX_1
#define PCI_DEVICE_ID_AUREAL_VORTEX_1	0x0001
#endif
#ifndef PCI_DEVICE_ID_AUREAL_VORTEX_2
#define PCI_DEVICE_ID_AUREAL_VORTEX_2	0x0002
#endif
#ifndef PCI_DEVICE_ID_AUREAL_ADVANTAGE
#define PCI_DEVICE_ID_AUREAL_ADVANTAGE	0x0003
#endif
#ifndef PCI_DEVICE_ID_VIA_8365_1
#define PCI_DEVICE_ID_VIA_8365_1	0x8305
#endif
#ifndef PCI_DEVICE_ID_AMD_FE_GATE_7007
#define PCI_DEVICE_ID_AMD_FE_GATE_7007	0x7007
#endif

/* cs46xx */
#ifndef PCI_DEVICE_ID_CIRRUS_4610
#define PCI_DEVICE_ID_CIRRUS_4610	0x6001
#endif
#ifndef PCI_DEVICE_ID_CIRRUS_4612
#define PCI_DEVICE_ID_CIRRUS_4612	0x6003
#endif
#ifndef PCI_DEVICE_ID_CIRRUS_4615
#define PCI_DEVICE_ID_CIRRUS_4615	0x6004
#endif
#ifndef PCI_DEVICE_ID_INTEL_82371AB_3
#define PCI_DEVICE_ID_INTEL_82371AB_3	0x7113
#endif

/* cs5535audio */
#ifndef PCI_VENDOR_ID_NS
#define PCI_VENDOR_ID_NS		0x100b
#endif
#ifndef PCI_DEVICE_ID_NS_CS5535_AUDIO
#define PCI_DEVICE_ID_NS_CS5535_AUDIO	0x002e
#endif
#ifndef PCI_VENDOR_ID_AMD
#define PCI_VENDOR_ID_AMD		0x1022
#endif
#ifndef PCI_DEVICE_ID_AMD_CS5536_AUDIO
#define PCI_DEVICE_ID_AMD_CS5536_AUDIO	0x2093
#endif

/* emu10k1 */
#ifndef PCI_VENDOR_ID_CREATIVE
#define PCI_VENDOR_ID_CREATIVE		0x1102
#endif
#ifndef PCI_DEVICE_ID_CREATIVE_EMU10K1
#define PCI_DEVICE_ID_CREATIVE_EMU10K1	0x0002
#endif
#ifndef PCI_DEVICE_ID_CREATIVE_20K1
#define PCI_DEVICE_ID_CREATIVE_20K1	0x0005
#define PCI_DEVICE_ID_CREATIVE_20K2	0x000b
#define PCI_SUBDEVICE_ID_CREATIVE_SB0760	0x0024
#define PCI_SUBDEVICE_ID_CREATIVE_SB08801	0x0041
#define PCI_SUBDEVICE_ID_CREATIVE_SB08802	0x0042
#define PCI_SUBDEVICE_ID_CREATIVE_SB08803	0x0043
#define PCI_SUBDEVICE_ID_CREATIVE_HENDRIX	0x6000
#endif

#ifndef PCI_SUBDEVICE_ID_CREATIVE_SB1270
#define PCI_SUBDEVICE_ID_CREATIVE_SB1270 0x0062
#endif

/* ice1712 */
#ifndef PCI_VENDOR_ID_ICE
#define PCI_VENDOR_ID_ICE		0x1412
#endif
#ifndef PCI_DEVICE_ID_ICE_1712
#define PCI_DEVICE_ID_ICE_1712		0x1712
#endif

/* ice1724 */
#ifndef PCI_DEVICE_ID_VT1724
#define PCI_DEVICE_ID_VT1724		0x1724
#endif

/* nm256 */
#ifndef PCI_VENDOR_ID_NEOMAGIC
#define PCI_VENDOR_ID_NEOMEGIC		0x10c8
#endif
#ifndef PCI_DEVICE_ID_NEOMAGIC_NM256AV_AUDIO
#define PCI_DEVICE_ID_NEOMAGIC_NM256AV_AUDIO 0x8005
#endif
#ifndef PCI_DEVICE_ID_NEOMAGIC_NM256ZX_AUDIO
#define PCI_DEVICE_ID_NEOMAGIC_NM256ZX_AUDIO 0x8006
#endif
#ifndef PCI_DEVICE_ID_NEOMAGIC_NM256XL_PLUS_AUDIO
#define PCI_DEVICE_ID_NEOMAGIC_NM256XL_PLUS_AUDIO 0x8016
#endif

/* hdsp */
#ifndef PCI_DEVICE_ID_XILINX_HAMMERFALL_DSP
#define PCI_DEVICE_ID_XILINX_HAMMERFALL_DSP 0x3fc5
#endif

/* hdspm */
#ifndef PCI_DEVICE_ID_XILINX_HAMMERFALL_DSP_MADI
#define PCI_DEVICE_ID_XILINX_HAMMERFALL_DSP_MADI 0x3fc6
#endif

/* rme9652 */
#ifndef PCI_DEVICE_ID_XILINX_HAMMERFALL
#define PCI_DEVICE_ID_XILINX_HAMMERFALL	0x3fc4
#endif

/* trident */
#ifndef PCI_VENDOR_ID_TRIDENT
#define PCI_VENDOR_ID_TRIDENT		0x1023
#endif
#ifndef PCI_DEVICE_ID_TRIDENT_4DWAVE_DX 
#define PCI_DEVICE_ID_TRIDENT_4DWAVE_DX	0x2000
#endif
#ifndef PCI_DEVICE_ID_TRIDENT_4DWAVE_NX 
#define PCI_DEVICE_ID_TRIDENT_4DWAVE_NX	0x2001
#endif
#ifndef PCI_DEVICE_ID_SI_7018
#define PCI_DEVICE_ID_SI_7018		0x7018
#endif

/* ymfpci */
#ifndef PCI_VENDOR_ID_YAMAHA
#define PCI_VENDOR_ID_YAMAHA		0x1073
#endif
#ifndef PCI_DEVICE_ID_YAMAHA_724
#define PCI_DEVICE_ID_YAMAHA_724	0x0004
#endif
#ifndef PCI_DEVICE_ID_YAMAHA_724F
#define PCI_DEVICE_ID_YAMAHA_724F	0x000d
#endif
#ifndef PCI_DEVICE_ID_YAMAHA_740
#define PCI_DEVICE_ID_YAMAHA_740	0x000a
#endif
#ifndef PCI_DEVICE_ID_YAMAHA_740C
#define PCI_DEVICE_ID_YAMAHA_740C	0x000c
#endif
#ifndef PCI_DEVICE_ID_YAMAHA_744
#define PCI_DEVICE_ID_YAMAHA_744	0x0010
#endif
#ifndef PCI_DEVICE_ID_YAMAHA_754
#define PCI_DEVICE_ID_YAMAHA_754	0x0012
#endif

/* pdplus */
#ifndef PCI_VENDOR_ID_MARIAN
#define PCI_VENDOR_ID_MARIAN		0x1382
#endif
#ifndef PCI_DEVICE_ID_MARIAN_PRODIF_PLUS
#define PCI_DEVICE_ID_MARIAN_PRODIF_PLUS 0x2048
#endif

/* hda-intel */
#ifndef PCI_VENDOR_ID_DELL
#define PCI_VENDOR_ID_DELL		0x1028
#endif
#ifndef PCI_VENDOR_ID_DFI
#define PCI_VENDOR_ID_DFI		0x15bd
#endif

#ifndef PCI_DEVICE_ID_ATI_SBX00_SMBUS
#define PCI_DEVICE_ID_ATI_SBX00_SMBUS	0x4385
#endif

/* lola */
#ifndef PCI_VENDOR_ID_DIGIGRAM
#define PCI_VENDOR_ID_DIGIGRAM		0x1369
#endif

/* ad1889 */
#ifndef PCI_VENDOR_ID_ANALOG_DEVICES
#define PCI_VENDOR_ID_ANALOG_DEVICES	0x11d4
#endif

#ifndef PCI_DEVICE_ID_AD1889JS
#define PCI_DEVICE_ID_AD1889JS		0x1889
#endif

